@@ -1,5 +1,6 @@
 ################################################################################
 # © Copyright 2022 Zapata Computing Inc.
 ################################################################################
-from .backend import QuantumBackend
+from .circuit_runner import BaseCircuitRunner, CircuitRunner
 from .estimation import EstimationTask
+from .wavefunction_simulator import BaseWavefunctionSimulator, WavefunctionSimulator
